==> ij-parsing-core-0.0.7.jar: module-info.java <==
module aya.ij.parsing.core {
    /* static phase */ requires org.jetbrains.annotations;
    /* transitive */ requires kala.base;
    /* transitive */ requires kala.collection;
    /* transitive */ requires kala.collection.primitive;

    exports org.aya.kala;
    exports com.intellij.analysis;
    exports com.intellij.core;
    exports com.intellij.formatting.engine;
    exports com.intellij.formatting;
    exports com.intellij.indentation;
    exports com.intellij.lang.impl;
    exports com.intellij.lang.injection;
    exports com.intellij.lang.parser;
    exports com.intellij.lang;
    exports com.intellij.lexer;
    exports com.intellij.model.psi;
    exports com.intellij.openapi.application;
    exports com.intellij.openapi.components;
    exports com.intellij.openapi.diagnostic;
    exports com.intellij.openapi.fileTypes;
    exports com.intellij.openapi.progress;
    exports com.intellij.openapi.project;
    exports com.intellij.openapi.util.diff;
    exports com.intellij.openapi.util.io;
    exports com.intellij.openapi.util.text;
    exports com.intellij.openapi.util;
    exports com.intellij.openapi.vfs;
    exports com.intellij.psi.builder;
    exports com.intellij.psi.codeStyle.lineIndent;
    exports com.intellij.psi.codeStyle;
    exports com.intellij.psi.impl.source.codeStyle.lineIndent;
    exports com.intellij.psi.impl.source.codeStyle;
    exports com.intellij.psi.templateLanguages;
    exports com.intellij.psi.tree;
    exports com.intellij.psi.util;
    exports com.intellij.psi;
    exports com.intellij.util.containers;
    exports com.intellij.util.diff;
    exports com.intellij.util.io;
    exports com.intellij.util.text;
    exports com.intellij.util;
    exports com.intellij;

}

==> ij-parsing-core-0.0.12.jar: module-info.java <==
module aya.ij.parsing.core {
    /* static phase */ requires org.jetbrains.annotations;
    /* transitive */ requires kala.base;
    /* transitive */ requires kala.collection;
    /* transitive */ requires kala.collection.primitive;

    exports org.aya.kala;
    exports com.intellij.analysis;
    exports com.intellij.core;
    exports com.intellij.formatting.engine;
    exports com.intellij.formatting;
    exports com.intellij.indentation;
    exports com.intellij.lang.impl;
    exports com.intellij.lang.injection;
    exports com.intellij.lang.parser;
    exports com.intellij.lang;
    exports com.intellij.lexer;
    exports com.intellij.model.psi;
    exports com.intellij.openapi.application;
    exports com.intellij.openapi.components;
    exports com.intellij.openapi.diagnostic;
    exports com.intellij.openapi.fileTypes;
    exports com.intellij.openapi.progress;
    exports com.intellij.openapi.project;
    exports com.intellij.openapi.util.diff;
    exports com.intellij.openapi.util.registry;
    exports com.intellij.openapi.util.text;
    exports com.intellij.openapi.util;
    exports com.intellij.openapi.vfs;
    exports com.intellij.psi.builder;
    exports com.intellij.psi.codeStyle.lineIndent;
    exports com.intellij.psi.codeStyle;
    exports com.intellij.psi.impl.source.codeStyle.lineIndent;
    exports com.intellij.psi.impl.source.codeStyle;
    exports com.intellij.psi.templateLanguages;
    exports com.intellij.psi.tree;
    exports com.intellij.psi.util;
    exports com.intellij.psi;
    exports com.intellij.util.containers;
    exports com.intellij.util.diff;
    exports com.intellij.util.io;
    exports com.intellij.util.text;
    exports com.intellij.util;
    exports com.intellij;

}
